@@ -3,10 +3,10 @@ NPM Security Advisory to NVD CVE converter
 
 This module implements basic functionality to query npm registry for security advisories
 """
-import json
 import logging
 
 import requests
+import ujson
 
 import vdb.lib.config as config
 from vdb.lib.nvd import NvdSource
@@ -14,6 +14,7 @@ from vdb.lib.utils import (
     get_default_cve_data,
     serialize_vuln_list,
     convert_to_occurrence,
+    fix_text
 )
 
 logging.basicConfig(
@@ -69,13 +70,28 @@ class NpmSource(NvdSource):
         version_list = []
         tmpA = version_str.split("||")
         for ver in tmpA:
-            version_start = ""
+            version_start_including = ""
+            version_end_including = ""
+            version_start_excluding = ""
+            version_end_excluding = ""
             ver = ver.strip()
             tmpB = ver.split(" ")
-            if tmpB[0].startswith(">"):
-                version_start = tmpB[0].replace(">=", "").replace(">", "")
-            version_end = tmpB[len(tmpB) - 1].replace("<=", "").replace("<", "")
-            version_list.append([version_start, version_end])
+            if tmpB[0].startswith(">="):
+                version_start_including = tmpB[0].replace(">=", "")
+            elif tmpB[0].startswith(">"):
+                version_start_excluding = tmpB[0].replace(">", "")
+            if tmpB[len(tmpB) - 1].startswith("<="):
+                version_end_including = tmpB[len(tmpB) - 1].replace("<=", "")
+            elif tmpB[len(tmpB) - 1].startswith("<"):
+                version_end_excluding = tmpB[len(tmpB) - 1].replace("<", "")
+            version_list.append(
+                {
+                    "version_start_including": version_start_including,
+                    "version_end_including": version_end_including,
+                    "version_start_excluding": version_start_excluding,
+                    "version_end_excluding": version_end_excluding,
+                }
+            )
         return version_list
 
     def convert(self, adv_data):
@@ -105,24 +121,30 @@ class NpmSource(NvdSource):
                 version = v["vulnerable_versions"]
                 version_ranges = self.get_version_ranges(version)
                 for ver in version_ranges:
+                    version_start_including = ver["version_start_including"]
+                    version_end_including = ver["version_end_including"]
+                    version_start_excluding = ver["version_start_excluding"]
+                    version_end_excluding = ver["version_end_excluding"]
                     tdata = config.CVE_TPL % dict(
                         cve_id=cve_id,
                         cwe_id=cwe_id,
                         assigner=assigner,
-                        references=json.dumps(references),
-                        description=description,
+                        references=ujson.dumps(references),
+                        description=fix_text(description),
                         vectorString=vectorString,
                         vendor=vendor,
                         product=product,
                         version="*",
-                        version_start=ver[0],
-                        version_end=ver[1],
+                        version_start_including=version_start_including,
+                        version_end_including=version_end_including,
+                        version_start_excluding=version_start_excluding,
+                        version_end_excluding=version_end_excluding,
                         severity=severity,
                         attackComplexity=attackComplexity,
                         score=score,
                         publishedDate=publishedDate,
                         lastModifiedDate=lastModifiedDate,
                     )
-                    vuln = NvdSource.convert_vuln(json.loads(tdata, strict=False))
+                    vuln = NvdSource.convert_vuln(ujson.loads(tdata))
                     ret_data.append(vuln)
         return ret_data
